Coverage for /Users/davegaeddert/Developer/dropseed/plain/plain-oauth/plain/oauth/urls.py: 100%

1 from plain.urls import include, path

2

3 from . import views

4

5 default_namespace = "oauth"

6

7 urlpatterns = [

8 path(

9 "<str:provider>/",

10 include(

11 [

12 # Login and Signup are both handled here, because the intent is the same

13 path("login/", views.OAuthLoginView, name="login"),

14 path("connect/", views.OAuthConnectView, name="connect"),

15 path(

16 "disconnect/",

17 views.OAuthDisconnectView,

18 name="disconnect",

19 ),

20 path("callback/", views.OAuthCallbackView, name="callback"),

21 ]

22 ),

23 ),

24]